==> async_notifications-0.1.17.tar.gz: async_notifications-0.1.17/async_notifications/tasks.py <==
# encoding: utf-8
'''
Created on 20/12/2015

@author: luisza
'''

from __future__ import unicode_literals

from django.conf import settings
from django.core import mail
import importlib
import os

from .mail_utils import get_all_emails
from .models import EmailNotification
from .settings import MAX_PER_MAIL, SEND_ONLY_EMAIL

app = importlib.import_module(settings.CELERY_MODULE).app


def _send_email(obj, mails, bcc=None, cc=None):
    send_ok = False
    with mail.get_connection() as connection:
        message = mail.EmailMessage(obj.subject, obj.message,
                                    settings.DEFAULT_FROM_EMAIL,
                                    mails,
                                    bcc=bcc,
                                    cc=cc,
                                    connection=connection
                                    )
        message.content_subtype = "html"
        if obj.file:
            if os.path.isfile(settings.MEDIA_ROOT + obj.file.name):
                message.attach_file(settings.MEDIA_ROOT + obj.file.name)
        try:
            message.send()
            send_ok = True
        except:
            obj.problems = True
            obj.save()

    if send_ok:
        obj.sended = True
        obj.queued = False
        obj.problems = False
        obj.save()


@app.task
def send_email(obj):
    """
    Envía un correo 
    obj puede ser un pk o una instancia EmailNotification
    """
    if not isinstance(obj, EmailNotification):
        try:
            obj = EmailNotification.objects.get(pk=obj)
        except:
            return
    if SEND_ONLY_EMAIL:
        mails = SEND_ONLY_EMAIL
        bcc=None
        cc=None
    else:
        mails = list(get_all_emails(obj.recipient))
        bcc = list(get_all_emails(obj.bcc))
        cc = list(get_all_emails(obj.cc))
    while len(mails) > MAX_PER_MAIL:
        s_mails = mails[:MAX_PER_MAIL]
        mails = mails[MAX_PER_MAIL:]
        _send_email(obj, s_mails, bcc=bcc, cc=cc)
    if len(mails) > 0:
        _send_email(obj, mails, bcc=bcc, cc=cc)


@app.task
def send_daily():
    for email in EmailNotification.objects.filter(sended=False, enqueued=True):
        send_email(email)

==> async_notifications-0.1.18.tar.gz: async_notifications-0.1.18/async_notifications/tasks.py <==
# encoding: utf-8
'''
Created on 20/12/2015

@author: luisza
'''

from __future__ import unicode_literals

from django.conf import settings
from django.core import mail
import importlib
import os

from .mail_utils import get_all_emails
from .models import EmailNotification
from .settings import MAX_PER_MAIL, SEND_ONLY_EMAIL, SMTP_DEBUG

app = importlib.import_module(settings.CELERY_MODULE).app


def _send_email(obj, mails, bcc=None, cc=None):
    send_ok = False
    sent = 0
    with mail.get_connection() as connection:
        if SMTP_DEBUG:
            connection.connection.set_debuglevel(1)
        message = mail.EmailMessage(obj.subject, obj.message,
                                    settings.DEFAULT_FROM_EMAIL,
                                    mails,
                                    bcc=bcc,
                                    cc=cc,
                                    connection=connection
                                    )
        message.content_subtype = "html"
        if obj.file:
            if os.path.isfile(settings.MEDIA_ROOT + obj.file.name):
                message.attach_file(settings.MEDIA_ROOT + obj.file.name)
        try:
            message.send(fail_silently=False)
            send_ok = True
            sent+=1
        except Exception as e:
            obj.problems = True
            obj.save()
            print(e)

    if send_ok:
        obj.sended = True
        obj.enqueued = False
        obj.problems = False
        obj.save()
    return sent

@app.task
def send_email(obj):
    """
    Envía un correo 
    obj puede ser un pk o una instancia EmailNotification
    """
    sent=0
    if not isinstance(obj, EmailNotification):
        try:
            obj = EmailNotification.objects.get(pk=obj)
        except:
            return
    if SEND_ONLY_EMAIL:
        mails = SEND_ONLY_EMAIL
        bcc=None
        cc=None
    else:
        mails = list(get_all_emails(obj.recipient))
        bcc = list(get_all_emails(obj.bcc))
        cc = list(get_all_emails(obj.cc))
    while len(mails) > MAX_PER_MAIL:
        s_mails = mails[:MAX_PER_MAIL]
        mails = mails[MAX_PER_MAIL:]
        sent += _send_email(obj, s_mails, bcc=bcc, cc=cc)
    if len(mails) > 0:
        sent += _send_email(obj, mails, bcc=bcc, cc=cc)

    return sent

@app.task
def send_daily():
    sent = 0
    for email in EmailNotification.objects.filter(sended=False, enqueued=True):
        try:
            sent += send_email(email)
        except Exception as e:
            print(e)
    return "sent %d"%(sent,)
